@@ -41,7 +41,7 @@ ContactIndexer::~ContactIndexer()
 
 QStringList ContactIndexer::mimeTypes() const
 {
-    return QStringList() << KABC::Addressee::mimeType();
+    return QStringList() << KABC::Addressee::mimeType() << KABC::ContactGroup::mimeType();
 }
 
 bool ContactIndexer::indexContact(const Akonadi::Item& item)
@@ -87,6 +87,12 @@ bool ContactIndexer::indexContact(const Akonadi::Item& item)
     const Akonadi::Entity::Id colId = item.parentCollection().id();
     doc.addBoolTerm(colId, "C");
 
+    if (addresse.birthday().isValid()) {
+        const QString julianDay = QString::number(addresse.birthday().date().toJulianDay());
+        doc.addValue(0, julianDay);
+    }
+    //TODO index anniversary ?
+
     m_db->replaceDocument(item.id(), doc);
     return true;
 }
@@ -106,13 +112,13 @@ void ContactIndexer::indexContactGroup(const Akonadi::Item& item)
     doc.indexText(name);
     doc.indexText(name, "NA");
 
+
     // Parent collection
     Q_ASSERT_X(item.parentCollection().isValid(), "Baloo::ContactIndexer::index",
                "Item does not have a valid parent collection");
 
     const Akonadi::Entity::Id colId = item.parentCollection().id();
     doc.addBoolTerm(colId, "C");
-
     m_db->replaceDocument(item.id(), doc);
 }
 
