@@ -190,6 +190,34 @@ Baloo::Term recursiveEmailTermMapping(const Akonadi::SearchTerm &term)
     return Baloo::Term();
 }
 
+Baloo::Term recursiveCalendarTermMapping(const Akonadi::SearchTerm &term)
+{
+    if (!term.subTerms().isEmpty()) {
+        Baloo::Term t(mapRelation(term.relation()));
+        Q_FOREACH (const Akonadi::SearchTerm &subterm, term.subTerms()) {
+            const Baloo::Term newTerm = recursiveCalendarTermMapping(subterm);
+            if (newTerm.isValid()) {
+                t.addSubTerm(newTerm);
+            }
+        }
+        return t;
+    } else {
+        kDebug() << term.key() << term.value();
+#if 0
+        const Akonadi::EmailSearchTerm::EmailSearchField field = Akonadi::EmailSearchTerm::fromKey(term.key());
+        switch (field) {
+        case Akonadi::EmailSearchTerm::Subject:
+            return getTerm(term, "subject");
+        case Akonadi::EmailSearchTerm::Body:
+            return getTerm(term, "body");
+        default:
+            kWarning() << "unknown term " << term.key();
+        }
+#endif
+    }
+    return Baloo::Term();
+}
+
 Baloo::Term recursiveNoteTermMapping(const Akonadi::SearchTerm &term)
 {
     if (!term.subTerms().isEmpty()) {
@@ -268,16 +296,20 @@ QSet<qint64> SearchPlugin::search(const QString &akonadiQuery, const QList<qint6
         kDebug() << "mail query";
         query.setType("Email");
         t = recursiveEmailTermMapping(term);
-    } else if (mimeTypes.contains(KABC::Addressee::mimeType())) {
+    } else if (mimeTypes.contains(KABC::Addressee::mimeType()) || mimeTypes.contains(KABC::ContactGroup::mimeType())) {
         query.setType("Contact");
         t = recursiveContactTermMapping(term);
     } else if (mimeTypes.contains(QLatin1String("text/x-vnd.akonadi.note"))) {
         query.setType("Note");
         t = recursiveNoteTermMapping(term);
-    } else if (mimeTypes.contains(KABC::ContactGroup::mimeType())) {
-        query.setType("ContactGroups");
-        t = recursiveContactTermMapping(term);
+    } else if (mimeTypes.contains(QLatin1String("application/x-vnd.akonadi.calendar.event")) ||
+               mimeTypes.contains(QLatin1String("application/x-vnd.akonadi.calendar.todo")) ||
+               mimeTypes.contains(QLatin1String("application/x-vnd.akonadi.calendar.journal")) ||
+               mimeTypes.contains(QLatin1String("application/x-vnd.akonadi.calendar.freebusy"))) {
+        query.setType("Calendar");
+        t = recursiveCalendarTermMapping(term);
     }
+
     if (t.subTerms().isEmpty()) {
         kWarning() << "no terms added";
         return QSet<qint64>();
